window.Gleam.initSearch([{"doc":"ref","title":"ref","content":"# ref\n\n[![Package Version](https://img.shields.io/hexpm/v/ref)](https://hex.pm/packages/ref)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/ref/)\n\n```sh\ngleam add ref\n```\n```gleam\nimport ref\n\npub fn main() {\n  let myref = ref.cell(0)\n  io.debug(ref.get(myref))\n  // -&gt; 0\n\n  ref.set(myref, fn(a) { a + 1 })\n  ref.set(myref, fn(a) { a + 1 })\n  ref.set(myref, fn(a) { a + 1 })\n\n  io.debug(ref.get(myref))\n  // -&gt; 3\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/ref&gt;.\n","url":"index.html"},{"doc":"ref","title":"RefCell","content":"pub opaque type RefCell(a)\n The reference cell type for holding mutable data\n\nSynonyms:\nref.RefCell\nref RefCell","url":"ref.html#RefCell"},{"doc":"ref","title":"cell","content":"pub fn cell(contents: a) -&gt; RefCell(a)\n Public constructor for creating a new RefCell. The initial value is passed, and a RefCell containing that value is returned.\n # Examples\n \n let immutable_value: List(Int) = [1, 2, 3, 4]\n let mutable_copy: RefCell(List(Int)) = ref.cell(immutable_value)\n \nSynonyms:\nref.cell\nref cell","url":"ref.html#cell"},{"doc":"ref","title":"get","content":"pub fn get(cell: RefCell(a)) -&gt; a\n Used for extracting the held data in a RefCell.\n Once the value has been extracted with this function, any mutations on the Cell will not affect the data already extracted.\n On erlang, this may panic if the actor is dead. If you want to return a result instead, use try_get. On javascript, get should always be used.\n # Examples\n \n let state = ref.cell(20)\n ref.get(state) |&gt; io.debug\n // &gt; 20\n ref.set(state, fn(a) { a + 5 })\n ref.get(state) |&gt; io.debug\n // &gt; 25\n \nSynonyms:\nref.get\nref get","url":"ref.html#get"},{"doc":"ref","title":"kill","content":"pub fn kill(cell: RefCell(a)) -&gt; Nil\n On erlang, this will shut down the underlying actor holding the state of a RefCell. On javascript, this will do nothing,\n # Examples\n \n let state = ref.cell([1, 2, 3])\n ref.kill(state)\n ref.try_get(state) |&gt; io.debug\n // &gt; Error(_)\n \nSynonyms:\nref.kill\nref kill","url":"ref.html#kill"},{"doc":"ref","title":"map","content":"pub fn map(subj: RefCell(a), f: fn(a) -&gt; b) -&gt; RefCell(b)\n Map the result of a function taking a Cell&#39;s contents into a new RefCell. No mutation takes place\nSynonyms:\nref.map\nref map","url":"ref.html#map"},{"doc":"ref","title":"set","content":"pub fn set(cell: RefCell(a), operation: fn(a) -&gt; a) -&gt; a\n Pass a function that takes and returns the inner type of the RefCell, and set the contents of the cell to its return value\n # Examples\n \n let state = ref.cell([1, 2, 3])\n ref.set(state, fn(a) { list.map(a, fn(b) { b + 1 }) })\n // or\n use ls &lt;- ref.set(state)\n list.map(ls, fn(a) { a + 1 })\n // state -&gt; RefCell([2, 3, 4])\n \nSynonyms:\nref.set\nref set","url":"ref.html#set"},{"doc":"ref","title":"try_get","content":"pub fn try_get(cell: RefCell(a)) -&gt; Result(a, CallError(a))\n Similar to ref.get, but will return a result instead of panicking if the actor is dead.\n # Examples\n \n let state = ref.cell(20)\n ref.try_get(state) |&gt; io.debug\n // &gt; Ok(20)\n ref.set(state, fn(a) { a + 5 })\n ref.try_get(state) |&gt; io.debug\n // &gt; Ok(25)\n ref.kill(state)\n ref.try_get(state) |&gt; io.debug\n // &gt; Error(_)\n \nSynonyms:\nref.try_get\nref try_get","url":"ref.html#try_get"},{"doc":"ref","title":"ref","content":" A ref cell library for gleam. The implementation uses actors on the erlang target for keeping track of the values\n of references, so a new process is spawned for each mutable reference you create. These mutable references should\n only be used if mutability is absolutely required. Immutability should always be preferred, \n and this implementation loses the performance benefits that mutability generally provides.","url":"ref.html"}]);